@@ -14,22 +14,6 @@ void writer_base::close()
 	buffers_.clear();
 }
 
-aio_result writer_base::add_buffer(buffer_lease && buffer, aio_waiter & h)
-{
-	scoped_lock l(mtx_);
-	if (error_) {
-		return aio_result::error;
-	}
-	if (!buffer || !*buffer) {
-		return aio_result::ok;
-	}
-	auto r = do_add_buffer(l, std::move(buffer));
-	if (r == aio_result::wait) {
-		add_waiter(h);
-	}
-	return r;
-}
-
 aio_result writer_base::add_buffer(buffer_lease && buffer, event_handler & h)
 {
 	scoped_lock l(mtx_);
@@ -46,16 +30,6 @@ aio_result writer_base::add_buffer(buffer_lease && buffer, event_handler & h)
 	return r;
 }
 
-aio_result writer_base::finalize(aio_waiter & h)
-{
-	scoped_lock l(mtx_);
-	auto r = do_finalize(l);
-	if (r == aio_result::wait) {
-		add_waiter(h);
-	}
-	return r;
-}
-
 aio_result writer_base::finalize(event_handler & h)
 {
 	scoped_lock l(mtx_);
