@@ -49,6 +49,23 @@ file& file::operator=(file && op) noexcept
 	return *this;
 }
 
+namespace {
+DWORD to_access_mode(file::mode m)
+{
+	switch (m) {
+		case file::reading:
+			return GENERIC_READ;
+		case file::writing:
+			return GENERIC_WRITE;
+		case file::readwrite:
+			return GENERIC_READ|GENERIC_WRITE;
+		case file::appending:
+			return FILE_APPEND_DATA;
+	}
+	return 0;
+}
+}
+
 result file::open(native_string const& f, mode m, creation_flags d)
 {
 	close();
@@ -58,7 +75,7 @@ result file::open(native_string const& f, mode m, creation_flags d)
 	}
 
 	DWORD dispositionFlags;
-	if (m == writing || m == readwrite) {
+	if (m == writing || m == readwrite || m == appending) {
 		if (d & empty) {
 			dispositionFlags = CREATE_ALWAYS;
 		}
@@ -91,14 +108,7 @@ result file::open(native_string const& f, mode m, creation_flags d)
 		}
 		attr.lpSecurityDescriptor = sd;
 	}
-	DWORD access{};
-	if (m != writing) {
-		access |= GENERIC_READ;
-	}
-	if (m != reading) {
-		access |= GENERIC_WRITE;
-	}
-	fd_ = CreateFileW(f.c_str(), access, shareMode, &attr, dispositionFlags, FILE_FLAG_SEQUENTIAL_SCAN, nullptr);
+	fd_ = CreateFileW(f.c_str(), to_access_mode(m), shareMode, &attr, dispositionFlags, FILE_FLAG_SEQUENTIAL_SCAN, nullptr);
 
 	if (fd_ == INVALID_HANDLE_VALUE) {
 		auto const err = GetLastError();
@@ -292,7 +302,11 @@ result file::open(native_string const& f, mode m, creation_flags d)
 		flags |= O_RDONLY;
 	}
 	else {
-		flags |= (m == writing) ? O_WRONLY : O_RDWR;
+		flags |= (m == readwrite) ? O_RDWR : O_WRONLY;
+		if (m == appending) {
+			flags |= O_APPEND;
+		}
+
 		flags |= O_CREAT;
 		if (d & empty) {
 			flags |= O_TRUNC;
