@@ -404,7 +404,7 @@ bool hash_accumulator::is_digest(uint8_t const* ref, size_t s)
 
 std::vector<std::uint8_t> hash_accumulator::export_state()
 {
-	if (!impl_ || !impl_->selftest()) {
+	if (!impl_->selftest()) {
 		return {};
 	}
 	return impl_->export_state();
@@ -413,7 +413,7 @@ std::vector<std::uint8_t> hash_accumulator::export_state()
 bool hash_accumulator::import_state(std::vector<std::uint8_t> const& state)
 {
 	reinit();
-	if (!impl_ || !impl_->selftest()) {
+	if (!impl_->selftest()) {
 		return false;
 	}
 	bool ret = impl_->import_state(state);
