@@ -176,12 +176,12 @@ public:
 	impl(impl const&) = delete;
 	impl& operator=(impl const&) = delete;
 
-	bool create_pipes()
+	bool create_pipes(bool include_stderr)
 	{
 		return
 			in_.create(false, handler_ != nullptr) &&
 			out_.create(true, handler_ != nullptr) &&
-			err_.create(true, false);
+			(!include_stderr || err_.create(true, false));
 	}
 
 	void thread_entry()
@@ -206,7 +206,7 @@ public:
 			if (quit_) {
 				break;
 			}
-			
+
 			if (res > WAIT_OBJECT_0 && res < (WAIT_OBJECT_0 + n)) {
 				HANDLE h = handles[res - WAIT_OBJECT_0];
 				if (h == ol_read_.hEvent) {
@@ -262,7 +262,7 @@ public:
 
 		bool const inherit = redirect_mode != io_redirection::none;
 		if (inherit) {
-			if (!create_pipes()) {
+			if (!create_pipes(redirect_mode != io_redirection::redirect_except_stderr)) {
 				return false;
 			}
 		}
@@ -277,7 +277,7 @@ public:
 				return false;
 			}
 
-			if (redirect_mode == io_redirection::redirect) {
+			if (redirect_mode == io_redirection::redirect || redirect_mode == io_redirection::redirect_except_stderr) {
 				DWORD res = ReadFile(out_.read_, read_buffer_.get(64 * 1024), 64 * 1024, nullptr, &ol_read_);
 				DWORD err = GetLastError();
 				if (!res && err != ERROR_IO_PENDING) {
@@ -319,7 +319,7 @@ public:
 			}
 			handles[0] = in_.read_;
 			handles[1] = out_.write_;
-			handles[2] = err_.write_;
+			handles[2] = (redirect_mode == io_redirection::redirect_except_stderr) ? GetStdHandle(STD_ERROR_HANDLE) : err_.write_;
 
 			if (!UpdateProcThreadAttribute(si.lpAttributeList, 0, PROC_THREAD_ATTRIBUTE_HANDLE_LIST, handles, sizeof(handles), nullptr, nullptr)) {
 				DeleteProcThreadAttributeList(si.lpAttributeList);
@@ -371,29 +371,14 @@ public:
 			return;
 		}
 
-		auto process_event_filter = [&](event_loop::Events::value_type const& ev) -> bool {
-			if (ev.first != handler_) {
-				return false;
-			}
-			else if (ev.second->derived_type() == process_event::type()) {
-				return std::get<0>(static_cast<process_event const&>(*ev.second).v_) == &process_;
+		auto process_event_filter = [&](event_base const& ev) -> bool {
+			if (ev.derived_type() == process_event::type()) {
+				return std::get<0>(static_cast<process_event const&>(ev).v_) == &process_;
 			}
 			return false;
 		};
 
-		handler_->event_loop_.filter_events(process_event_filter);
-	}
-
-	template<typename Out, typename In>
-	constexpr Out clamped_cast(In in) noexcept
-	{
-		if (cmp_less(in, std::numeric_limits<Out>::min())) {
-			return std::numeric_limits<Out>::min();
-		}
-		if (cmp_less(std::numeric_limits<Out>::max(), in)) {
-			return std::numeric_limits<Out>::max();
-		}
-		return static_cast<Out>(in);
+		handler_->filter_events(process_event_filter);
 	}
 
 	bool kill(bool force = true, duration const& timeout = {})
@@ -449,32 +434,6 @@ public:
 
 		return true;
 	}
-	
-	template<class A, class B>
-	constexpr bool cmp_less(A a, B b) noexcept
-	{
-		static_assert(std::is_integral_v<A>);
-		static_assert(std::is_integral_v<B>);
-		if constexpr (std::is_signed_v<A> == std::is_signed_v<B>) {
-			return a < b;
-		}
-		else if constexpr (std::is_signed_v<A>) {
-			if (a < 0) {
-				return true;
-			}
-			else {
-				return std::make_unsigned_t<A>(a) < b;
-			}
-		}
-		else {
-			if (b < 0) {
-				return false;
-			}
-			else {
-				return a < std::make_unsigned_t<B>(b);
-			}
-		}
-	}
 
 	rwresult read(void* buffer, size_t len)
 	{
@@ -721,12 +680,12 @@ public:
 	impl(impl const&) = delete;
 	impl& operator=(impl const&) = delete;
 
-	bool create_pipes()
+	bool create_pipes(bool include_stderr)
 	{
 		return
 			in_.create() &&
 			out_.create() &&
-			err_.create();
+			(!include_stderr || err_.create());
 	}
 
 	void thread_entry()
@@ -784,7 +743,7 @@ public:
 			return false;
 		}
 
-		if (redirect_mode != io_redirection::none && !create_pipes()) {
+		if (redirect_mode != io_redirection::none && !create_pipes(redirect_mode != io_redirection::redirect_except_stderr)) {
 			kill();
 			return false;
 		}
@@ -829,7 +788,7 @@ public:
 				// at stdin/out/err as we do not want to have these re-used for other things.
 				if (dup2(in_.read_, STDIN_FILENO) == -1 ||
 					dup2(out_.write_, STDOUT_FILENO) == -1 ||
-					dup2(err_.write_, STDERR_FILENO) == -1)
+					(redirect_mode != io_redirection::redirect_except_stderr && dup2(err_.write_, STDERR_FILENO) == -1))
 				{
 					_exit(-1);
 				}
@@ -895,17 +854,14 @@ public:
 			return;
 		}
 
-		auto process_event_filter = [&](event_loop::Events::value_type const& ev) -> bool {
-			if (ev.first != handler_) {
-				return false;
-			}
-			else if (ev.second->derived_type() == process_event::type()) {
-				return std::get<0>(static_cast<process_event const&>(*ev.second).v_) == &process_;
+		auto process_event_filter = [&](event_base const& ev) -> bool {
+			if (ev.derived_type() == process_event::type()) {
+				return std::get<0>(static_cast<process_event const&>(ev).v_) == &process_;
 			}
 			return false;
 		};
 
-		handler_->event_loop_.filter_events(process_event_filter);
+		handler_->filter_events(process_event_filter);
 	}
 
 	bool do_waitpid(bool wait = false)
@@ -1051,7 +1007,7 @@ public:
 			case EAGAIN:
 				{
 					scoped_lock l(mutex_);
-					waiting_read_ = true;
+					waiting_write_ = true;
 					poller_.interrupt(l);
 				}
 				return rwresult{rwresult::wouldblock, err};
