@@ -1350,6 +1350,16 @@ int listen_socket::listen(address_type family, int port)
 				setsockopt(fd_, IPPROTO_IPV6, IPV6_V6ONLY, reinterpret_cast<char const*>(&enable), sizeof(enable));
 			}
 
+			{
+				int enable = 1;
+#if FZ_WINDOWS
+				int const flag = SO_EXCLUSIVEADDRUSE;
+#else
+				int const flag = SO_REUSEADDR;
+#endif
+				(void)setsockopt(fd_, SOL_SOCKET, flag, (const char*)&enable, sizeof(enable));
+			}
+
 			res = ::bind(fd_, addr->ai_addr, addr->ai_addrlen);
 			if (!res) {
 				break;
