@@ -539,13 +539,13 @@ std::string normalize_hyphens(std::string_view const& in)
 {
 	std::string ret(in.data(), in.size());
 
-	fz::replace_substrings(ret, u8"\u2010", "-"); // Hyphen
-	fz::replace_substrings(ret, u8"\u2011", "-"); // Non-Breaking-Hyphen
-	fz::replace_substrings(ret, u8"\u2012", "-"); // Figure Dash
-	fz::replace_substrings(ret, u8"\u2013", "-"); // En Dash
-	fz::replace_substrings(ret, u8"\u2014", "-"); // Em Dash
-	fz::replace_substrings(ret, u8"\u2015", "-"); // Horizontal Bar
-	fz::replace_substrings(ret, u8"\u2212", "-"); // Minus Sign
+	fz::replace_substrings(ret, reinterpret_cast<char const*>(u8"\u2010"), "-"); // Hyphen
+	fz::replace_substrings(ret, reinterpret_cast<char const*>(u8"\u2011"), "-"); // Non-Breaking-Hyphen
+	fz::replace_substrings(ret, reinterpret_cast<char const*>(u8"\u2012"), "-"); // Figure Dash
+	fz::replace_substrings(ret, reinterpret_cast<char const*>(u8"\u2013"), "-"); // En Dash
+	fz::replace_substrings(ret, reinterpret_cast<char const*>(u8"\u2014"), "-"); // Em Dash
+	fz::replace_substrings(ret, reinterpret_cast<char const*>(u8"\u2015"), "-"); // Horizontal Bar
+	fz::replace_substrings(ret, reinterpret_cast<char const*>(u8"\u2212"), "-"); // Minus Sign
 
 	return ret;
 }
